/**
 * @fileoverview Enforce tabIndex value is not greater than zero.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _jsxAstUtils = require('jsx-ast-utils');

var errorMessage = 'Avoid positive integer values for tabIndex.';

module.exports = function (context) {
  return {
    JSXAttribute: function JSXAttribute(attribute) {
      var name = attribute.name.name;
      var normalizedName = name.toUpperCase();

      // Check if tabIndex is the attribute
      if (normalizedName !== 'TABINDEX') {
        return;
      }

      // Only check literals because we can't infer values from certain expressions.
      var value = Number((0, _jsxAstUtils.getLiteralPropValue)(attribute));

      if (isNaN(value) || value <= 0) {
        return;
      }

      context.report({
        node: attribute,
        message: errorMessage
      });
    }
  };
};

module.exports.schema = [{ type: 'object' }];